@@ -206,6 +206,8 @@ struct ast_channel {
 
 	char context[AST_MAX_CONTEXT];			/*!< Dialplan: Current extension context */
 	char exten[AST_MAX_EXTENSION];			/*!< Dialplan: Current extension number */
+	char lastcontext[AST_MAX_CONTEXT];		/*!< Dialplan: Previous extension context */
+	char lastexten[AST_MAX_EXTENSION];		/*!< Dialplan: Previous extension number */
 	char macrocontext[AST_MAX_CONTEXT];		/*!< Macro: Current non-macro context. See app_macro.c */
 	char macroexten[AST_MAX_EXTENSION];		/*!< Macro: Current non-macro extension. See app_macro.c */
 	char unbridged;							/*!< non-zero if the bridge core needs to re-evaluate the current
@@ -214,7 +216,7 @@ struct ast_channel {
 	char dtmf_digit_to_emulate;			/*!< Digit being emulated */
 	char sending_dtmf_digit;			/*!< Digit this channel is currently sending out. (zero if not sending) */
 	struct timeval sending_dtmf_tv;		/*!< The time this channel started sending the current digit. (Invalid if sending_dtmf_digit is zero.) */
-	struct stasis_topic *topic;		/*!< Topic for trhis channel */
+	struct stasis_topic *topic;		/*!< Topic for this channel */
 	struct stasis_forward *channel_forward; /*!< Subscription for event forwarding to all channel topic */
 	struct stasis_forward *endpoint_forward;	/*!< Subscription for event forwarding to endpoint's topic */
 	struct ast_stream_topology *stream_topology; /*!< Stream topology */
@@ -345,8 +347,16 @@ const char *ast_channel_context(const struct ast_channel *chan)
 {
 	return chan->context;
 }
+const char *ast_channel_lastcontext(const struct ast_channel *chan)
+{
+	return chan->lastcontext;
+}
 void ast_channel_context_set(struct ast_channel *chan, const char *value)
 {
+	if (!*chan->lastcontext || strcmp(value, chan->context)) {
+		/* only copy to last context when it changes, unless it's empty to begin with */
+		ast_copy_string(chan->lastcontext, chan->context, sizeof(chan->lastcontext));
+	}
 	ast_copy_string(chan->context, value, sizeof(chan->context));
 	ast_channel_snapshot_invalidate_segment(chan, AST_CHANNEL_SNAPSHOT_INVALIDATE_DIALPLAN);
 }
@@ -354,8 +364,16 @@ const char *ast_channel_exten(const struct ast_channel *chan)
 {
 	return chan->exten;
 }
+const char *ast_channel_lastexten(const struct ast_channel *chan)
+{
+	return chan->lastexten;
+}
 void ast_channel_exten_set(struct ast_channel *chan, const char *value)
 {
+	if (!*chan->lastexten || strcmp(value, chan->exten)) {
+		/* only copy to last exten when it changes, unless it's empty to begin with */
+		ast_copy_string(chan->lastexten, chan->exten, sizeof(chan->lastexten));
+	}
 	ast_copy_string(chan->exten, value, sizeof(chan->exten));
 	ast_channel_snapshot_invalidate_segment(chan, AST_CHANNEL_SNAPSHOT_INVALIDATE_DIALPLAN);
 }
@@ -1310,14 +1328,14 @@ void ast_channel_dialed_causes_clear(const struct ast_channel *chan)
 	ao2_callback(chan->dialed_causes, OBJ_UNLINK | OBJ_NODATA | OBJ_MULTIPLE, NULL, NULL);
 }
 
-/* \brief Hash function for pvt cause code frames */
+/*! \brief Hash function for pvt cause code frames */
 static int pvt_cause_hash_fn(const void *vpc, const int flags)
 {
 	const struct ast_control_pvt_cause_code *pc = vpc;
 	return ast_str_hash(ast_tech_to_upper(ast_strdupa(pc->chan_name)));
 }
 
-/* \brief Comparison function for pvt cause code frames */
+/*! \brief Comparison function for pvt cause code frames */
 static int pvt_cause_cmp_fn(void *obj, void *vstr, int flags)
 {
 	struct ast_control_pvt_cause_code *pc = obj;
