@@ -184,6 +184,41 @@ int ast_format_def_unregister(const char *name)
 	return res;
 }
 
+FILE *ast_file_mkftemp(char *template, mode_t mode)
+{
+	FILE *p = NULL;
+	int pfd = mkstemp(template);
+	chmod(template, mode);
+	if (pfd > -1) {
+		p = fdopen(pfd, "w+");
+		if (!p) {
+			close(pfd);
+			pfd = -1;
+		}
+	}
+	return p;
+}
+
+int ast_file_fdtemp(const char *path, char **filename, const char *template_name)
+{
+	int fd;
+
+	if (ast_asprintf(filename, "%s/%s", path, template_name) < 0) {
+		ast_log(LOG_ERROR, "Failed to set up temporary file path\n");
+		return -1;
+	}
+
+	ast_mkdir(path, 0644);
+
+	if ((fd = mkstemp(*filename)) < 0) {
+		ast_log(LOG_NOTICE, "Failed to create temporary file\n");
+		ast_free(*filename);
+		return -1;
+	}
+
+	return fd;
+}
+
 int ast_stopstream(struct ast_channel *tmp)
 {
 	ast_channel_lock(tmp);
@@ -271,7 +306,7 @@ int ast_writestream(struct ast_filestream *fs, struct ast_frame *f)
 static int copy(const char *infile, const char *outfile)
 {
 	int ifd, ofd, len;
-	char buf[4096];	/* XXX make it lerger. */
+	char buf[4096];	/* XXX make it larger. */
 
 	if ((ifd = open(infile, O_RDONLY)) < 0) {
 		ast_log(LOG_WARNING, "Unable to open %s in read-only mode\n", infile);
@@ -650,8 +685,8 @@ static int is_remote_path(const char *filename)
 /*!
  * \brief test if a file exists for a given format.
  * \note result_cap is OPTIONAL
- * \retval 1, true and result_cap represents format capabilities file exists in.
- * \retval 0, false
+ * \retval 1 true and result_cap represents format capabilities file exists in.
+ * \retval 0 false
  */
 static int fileexists_test(const char *filename, const char *fmt, const char *lang,
 			   char *buf, int buflen, struct ast_format_cap *result_cap)
@@ -700,8 +735,8 @@ static int fileexists_test(const char *filename, const char *fmt, const char *la
  * \param result_cap OPTIONAL format capabilities result structure
  *        returns what formats the file was found in.
  *
- * \retval 1, true. file exists and result format is set
- * \retval 0, false. file does not exist.
+ * \retval 1 true. file exists and result format is set
+ * \retval 0 false. file does not exist.
  */
 static int fileexists_core(const char *filename, const char *fmt, const char *preflang,
 			   char *buf, int buflen, struct ast_format_cap *result_cap)
