@@ -27,6 +27,7 @@
 /*** MODULEINFO
 	<use>pjproject</use>
 	<use type="module">res_pjsip</use>
+	<use type="module">res_pjsip_outbound_registration</use>
 	<support_level>extended</support_level>
  ***/
 
@@ -239,7 +240,7 @@ static struct prometheus_metric core_metrics[] = {
 		get_last_reload_cb),
 };
 
-/**
+/*!
  * \internal
  * \brief Compare two metrics to see if their name / labels / values match
  *
@@ -409,14 +410,13 @@ void prometheus_metric_free(struct prometheus_metric *metric)
 	}
 }
 
-/**
+/*!
  * \internal
  * \brief Common code for creating a metric
  *
  * \param name The name of the metric
  * \param help Help string to output when rendered. This must be static.
  *
- * \retval \c prometheus_metric on success
  * \retval NULL on failure
  */
 static struct prometheus_metric *prometheus_metric_create(const char *name, const char *help)
@@ -475,7 +475,7 @@ static const char *prometheus_metric_type_to_string(enum prometheus_metric_type
 	}
 }
 
-/**
+/*!
  * \internal
  * \brief Render a metric to text
  *
@@ -1003,6 +1003,7 @@ AST_MODULE_INFO(ASTERISK_GPL_KEY, AST_MODFLAG_GLOBAL_SYMBOLS | AST_MODFLAG_LOAD_
 	.reload = reload_module,
 	.load_pri = AST_MODPRI_DEFAULT,
 #ifdef HAVE_PJPROJECT
-	.requires = "res_pjsip",
+	/* This module explicitly calls into res_pjsip if Asterisk is built with PJSIP support, so they are required. */
+	.requires = "res_pjsip,res_pjsip_outbound_registration",
 #endif
 );
